#
# spec file for package xfce4-dev-tools
#
# Copyright (c) 2020-2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
Name:           xfce4-dev-tools
Version:        4.18.1
Release:        1.1
Summary:        Xfce Development Tools
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://www.xfce.org/
Source0:        https://archive.xfce.org/src/xfce/xfce4-dev-tools/4.18/%{name}-%{version}.tar.bz2
BuildRequires:  pkgconfig(glib-2.0) >= 2.66.0
BuildRequires:  xsltproc
Requires:       autoconf
Requires:       automake
Requires:       intltool
Requires:       libtool
Requires:       make

%description
The Xfce development tools are a collection of tools and macros for
Xfce developers and people that want to build unreleased development
versions of Xfce.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode
%else
%configure
%endif
%make_build

%install
%make_install

%files
%doc AUTHORS ChangeLog HACKING NEWS README.md
%license COPYING
%{_bindir}/xdt-autogen
%{_bindir}/xfce-build
%{_bindir}/xdt-csource
%{_bindir}/xfce-do-release
%{_bindir}/xfce-get-release-notes
%{_bindir}/xfce-get-translations
%{_bindir}/xfce-update-news
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/xdt-*
%{_mandir}/man1/xdt-csource.1.gz

%changelog
* Wed Oct 18 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.1
  * Remove -Wdeclaration-after-statement from list of enabled warnings
  * Add check for xsltproc (#60)
  * xdt-autogen: Fixed wrong make displayed on FreeBSD
  * Add new macro XDT_CHECK_PACKAGE_BINARY
  * Add new macro XDT_CHECK_OPTIONAL_FEATURE
* Thu Dec 22 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.0
  * Bump requirements for Xfce 4.18
  * Remove _service file
- Update to version 4.17.2
  * Add new libsoup3 to the builder
  * xfce-do-release: unification of update version 'sed' command
  * xfce-do-release: match multiple spaces for git version replace
  * bump copyright year to 2022
- Update to version 4.17.1
  * Warn about GLib functions newer than the checked GLib version
  * Drop the test altogether
  * xdt-autogen: Fix deprecation warning from grep 3.8
  * Use GLib structured logging
  * xdt-autogen: simplify do_version_check()
  * Add new dependencies to the builder
  * Do not run useless distcheck in CI
  * Add favicon to Xfce API docs
  * Bump our xfce builder to ubuntu 22.04
  * Add autopoint to xfce-build
  * Add a workaround for thunar documentation generation
  * Update COPYING
  * xfce-build: Fix build with SELinux (!58)
  * xfce-update-news: Add release date and adjust separator
  * xfce-do-release: Make warnings more visible
  * xfce-do-release: Check the copyright year in `configure.ac*`
  * xfce-do-release: Extend `configure.ac.in` update to `configure.ac`
  * xdt-autogen: Fallback on `n` as IFS if `1` is not supported
  * Fix exclusion of `xdt-autogen.in` in `.gitignore`
  * Update developer.xfce.org home to add tumbler
  * Add tumbler to xfce-build container
  * Fix "image:" name in .gitlab-ci.yml
  * Add libsensors4-dev to build-container
  * Try to bump docker-dind image
  * xfce-do-release: Update Appdata file
  * gitlabci: Ensure distcheck still runs
  * gitlabci: Add release stage that retains tarballs
  * Add lm-sensors to dependencies, for xfce4-sensors-plugins CI
  * Separate CFLAGS from CXXFLAGS
- Update to version 4.17.0
  * Try to build higher version available tag
  * xfce-do-release: A review of confirmation prompts
  * helpers: Improve script portability
  * Improve Xfce Developer Center (developer.xfce.org)
  * xdt-features.m4: Always enable compilation warnings
  * g_locale_to_utf8 is misspelled as g_local_to_utf8
  * xfce-build: Always pick the latest stable release
  * Create the m4/ if it does not exists
  * Use autoreconf to bootstrap xfce4-dev-tools itself
  * Use autoreconf to bootstrap autotools
  * xfce-do-release: Check for `docker` installed
  * Add dependencies to build thunarx-python CI
  * Fix location of apidocs
  * xfce-build: Fix conditional in gitlabci
  * Export apidocs as GitLab artifacts
  * Get rid of glib-gettextize usage and XGETTEXT_ARGS custom args
  * Remove obsolete AM_GLIB_GNU_GETTEXT
  * helpers: Fix command-line if git-config core.editor is unset
  * Update obsolete m4 macros
  * helpers: Add 'xfce-build describe' command
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  - Bump glib to 2.50 based on xfce4.16 roadmap
  - Do not process @LINGUAS@ at xdt-autogen stage
  - Fail xfce-build container generation if there is any error
  - helpers: Prefer xfce-build over xfce-test (Fixes #38)
  - helpers: Add new helper xfce-open-gitlab
  - helpers: Add helper to locally run xfce-build
  - helpers: Add xfce-build 'pull' argument
  - xfce-build: Add Thunar to container (Fixes #40)
  - Disable CFLAGS override when building CI container
  - use strict CFLAGS to catch common mistakes in ci pipeline
  - Add xvfb on xfce-build
* Mon Nov  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.1
  * get-translations: Fix line wrapping
  * xdt-autogen: Various small improvements
  * xdt-autogen: Properly handle whitespaces in filenames
  * xdt-autogen: Use sed instead of tr to replace strings
  * Updates README.md
  * xfce-build: Add libclutter-1.0-dev for xfdashboard build
  * Update .gitignore
  * helpers: Use blank line for tags message
  * helpers: Reuse release notes from NEWS for tag message
  * helpers: Simplify xfce-update-news
  * helpers: Do not strip NEWS blank line at EOF
  * helpers: Install xfce-do-release
  * xfce-build: Add depend for mousepad (Fixes #37)
  * helpers: Add do-release helper and Readme
  * xfce-build: Install python3 version of distutils-extra
  * helpers: Make get-translations executable
  * get-translations: Remove last comma
  * get-translations: Correctly get locale from commit messages
  * xfce-build: Replace build-dep with package names
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.0
  * New macro XDT_VERSION_INIT(SEMVER[, TAG])
    This macro takes care of setting up the version numbering.
    It will define the following macros based on SEMVER and TAG:
  - xdt_version
  - xdt_version_major
  - xdt_version_minor
  - xdt_version_micro
  - xdt_version_tag
  - xdt_version_build
  - xdt_debug_default
    If TAG isn't specified, the xdt_version_tag and xdt_version_git
    will be empty and xdt_debug_default will be set to "minimum",
    otherwise the xdt_version_build will contain a git hash and
    xdt_debug_default will be set to "yes"
  * XDT_I18N macro will now automatically find the linguas if none
    are specified during the autoconf run.
  * Install m4 macros in default search dir.
    This makes autoconf find the macros by default.
    By setting version via XDT_VERSION_INIT and using XDT_I18N
    without arguments, this is no longer necessary to use a separate
    configure.ac.in and a plain configure.ac can be used
  * xfce4-dev-tools now also handle the CI (docker container,
    .gitlab-ci.yml templates files etc) on our new gitlab instance.
  * New helpers are also available (xfce-get-release-notes,
    xfce-get-translations, xfce-update-news)
  * Use datarootdir instead of datadir
  * xdt-autogen: explicitly set search path for m4 macros
  * Add two new helpers to help releasers
  * Install m4 macros into default $datadir/aclocal
  * Update README for new gitlab urls
  * xdt-autogen: Improve and simplify linguas detection
  * Let XDT_I18N automatically find the po/*.po as default
  * Let configure generate the xdt-autogen script
  * Implement XDT_VERSION_INIT
  * Add manpage and tests to xdt-csource
  * Add xfce4-dev-tools build in addition to container build
  * Check BEFORE_SHA along with changes to .po files
  * gitlabci: Ensure to run autogen in distcheck stage
  * Switch to "foreign" mode for automake
  * Add CI templates notes
  * Update README with explanation of Dockerfile
  * Fix whitespace error
  * Add helper script to get all
  * Integrate xfce-build container build/creation
  * Translation updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Sun Aug 11 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.0
  * Bump to 4.14.0
- Added bcond to build with git master source
- Cleaned spec file
* Thu Jun 27 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to Version 4.13.0
  * Merge exo-csource modifications in xdt-csource
  * xdt-csource will replace exo-csource (projects using
    exo-csource need to be updated)
  * The work started in issue bxo#6449 but the full migration has
    never been done.
  * Remove svn support in xdt-autogen
  * Simplify a bit the XDT_AUTOGEN_REQUIRED_VERSION detection
  * Remove the check of the unused doc submodule
  * Remove useless macros: m4macros/xdt-python.m4
    and m4macros/xdt-xfce.m4 are not used
  * Remove xdt-commit, used to generate Changelog, now done via
    make distcheck
  * No -Wshadow flag for enable_debug=full (bxo#11637).
    Use it only for enable_debug=yes.
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - bump version
  - require xfce4-panel-4.11 for panel plugins
  - restore AC_REVISION
* Tue Feb 17 2015 gber@opensuse.org
- update to version 4.11.1
  - update list of files to clean with xdt-autogen
  - remove definitions related to the obsolete xfce-mcs-manager
  - remove obsolete check for threaded panels (<= 4.1.90)
  - bump dependencies for xfce4-dev-tools and m4macros
  - fix autotools m4 warning
  - fix out of source building (bxo#10899)
  - display warning if AC_PROG_INTLTOOL is used (bxo#8930)
* Wed Apr 30 2014 gber@opensuse.org
- update to version 4.11.0
  - remove FORTIFY_SOURCE=2
  - some build improvements
  - correctly quote AC_COMPILE_IFELSE macro
  - avoid gnu_printf warnings in debugging in gcc 4.8
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - bump glib dependency to 2.24
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.2
  - fix license
  - remove the old BM_ macros
  - use ?_VERSION for special versioned binary detection
  - never disable checks
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.1
  - add support for LT_PREREQ
  - remove spec file and rpm build target
  - do not create a gzip tarball
  - never use xdt-autogen in autogen.sh
  - fix FSF address and add missing licenses
  - don't use -g3 for full debugging
  - use pkg-config macro for detection
  - port exo-csource to xdt-csource
* Tue Mar 27 2012 gber@opensuse.org
- added source URL
* Fri Aug  5 2011 coolo@novell.com
- add requires to called tools (hope I catched them all)
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  - check for glibtoolize
* Mon Dec 27 2010 gber@opensuse.org
- corrected group
- improved description
* Wed Dec  1 2010 prusnak@opensuse.org
- cleanup spec file
* Mon Nov  8 2010 prusnak@opensuse.org
- updated to 4.7.3
  * build ChangeLog from GIT
  * add check stage for documentation submodules
  * check for automake 1.11
  * check if $1 is a file before calling cat
* Thu Jul 22 2010 andrea@opensuse.org
- revert back to 4.6.0 for now
- make package noarch
* Wed Nov 11 2009 prusnak@suse.cz
- updated to 4.7.2
  - changes from 4.7.0
  - Do @REVISION@ and @LINGUAS@ substitutions in xdt-autogen instead of
    requiring people to put it in their autogen.sh files.
  - Also support the newer IT_PROG_INTLTOOL macro
  - Added --version and -V options to display the xdt-autogen version
  - Added ability for autogen.sh scripts to set an environment
    variable XDT_AUTOGEN_REQUIRED_VERSION to depend on a particular version
    of xdt-autogen.
  - Add a bunch more compiler warnings for --enable-debug, and a new macro
    XDT_SUPPORTED_FLAGS() that tests whether the compiler supports particular
    option flags.
  - changes from 4.7.1
  - Also support the newer AC_CONFIG_HEADERS macro.
  - Add XDT_FEATURE_VISIBILITY to check for and enable symbol visibility
    support (only useful for building libraries).
  - Add XDT_FEATURE_LINKER_OPTS that checks for and enables useful linker
    optimizations if supported.  This currently only checks for
  - -as-needed and -O1, but more may be added in the future.
  - Beef up XDT_FEATURE_DEBUG:
  * Add new 'minimum' debug level, which is now the default and behaves
    similarly to the old 'no' default.
  * Debug level 'no' disables many glib/gobject-related checks and
    asserts (this is not really recommended).
  * Debug level 'full' disables code optimization.
  * The macro now takes an argument to specify the default debug level.
  - changes from 4.7.2
  - Brown bag: fix typo that breaks XDT_FEATURE_LINKER_OPTS
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Mon Dec  3 2007 bwalle@suse.de
- update to 4.4.0.1
  o Updated and new translations.
* Sat Jun 23 2007 bwalle@suse.de
- replaced group 'System/GUI/Other' by 'System/GUI/XFCE'
* Tue May 22 2007 prusnak@suse.cz
- sync with BuildService
* Tue Jan 30 2007 ro@suse.de
- added directory to filelist
* Mon Jan 29 2007 pnemec@suse.cz
- package merged from BuildService into AutoBuild
* Sun Jan 21 2007 bwalle@suse.de
- upgraded to 4.4.0
